@@ -2,5 +2,5 @@ from . import (
     JwtHttp,
     Util,
     Validator,
-    Notifications
+    firebase
 )
