@@ -1,8 +1,7 @@
 from requests.structures import CaseInsensitiveDict
 from requests import post
 
-class Firebase:
-    def send_notifications(sender,receiver,title,body):
+def send_notifications(sender,receiver,title,body):
         url = "https://fcm.googleapis.com/fcm/send"
 
         headers = CaseInsensitiveDict()
@@ -22,7 +21,4 @@ class Firebase:
                     """
 
         resp = post(url, headers=headers, data=data)
-        return resp
-
-firebase = Firebase()
-send_notifications=Firebase.send_notifications()
+        return resp
\ No newline at end of file
